@@ -221,7 +221,7 @@ fn can_write_hre_problem() {
                         demand: Some(vec![1]),
                         ..create_empty_job_task()
                     }]),
-                    skills: Some(vec!["skill1".to_string()]),
+                    skills: Some(JobSkills { all_of: Some(vec!["skill1".to_string()]), one_of: None, none_of: None }),
                     ..create_empty_job()
                 },
                 Job {
@@ -358,7 +358,6 @@ fn can_write_hre_problem() {
             profiles: vec![Profile { name: "normal_car".to_string(), profile_type: "car".to_string(), speed: None }],
         },
         objectives: None,
-        config: None,
     };
     let mut buffer = String::new();
     let writer = unsafe { BufWriter::new(buffer.as_mut_vec()) };
